@@ -9,7 +9,7 @@ from analyst_klondike.state.app_dispatch import app_dispatch
 
 def _demo_file_path() -> str:
     this_file_dir = os.path.dirname(os.path.realpath(__file__))
-    return os.path.join(this_file_dir, "demo.json")
+    return os.path.join(this_file_dir, "demo.yaml")
 
 
 def start_demo_quiz():
