@@ -42,7 +42,7 @@ from analyst_klondike.features.code_explorer.code_explorer_reducer import (
     QuizNodeCollapseAction,
     QuizNodeExpandAction
 )
-from analyst_klondike.features.data_context.save_action import save_to_json
+from analyst_klondike.features.data_context.save_action import save_to_yaml
 
 from analyst_klondike.features.message_box.actions import (
     DisplayMessageBoxAction,
@@ -222,7 +222,7 @@ class EditorScreen(Screen[Any]):
 
     def action_save_quiz_to_file(self) -> None:
         state = get_state()
-        save_to_json(state, self.app)
+        save_to_yaml(state, self.app)
 
     def action_display_help(self) -> None:
         app_dispatch(DisplayMessageBoxAction(_WELLCOME_MESSAGE))
