@@ -5,7 +5,7 @@ import pyperclip
 
 
 from analyst_klondike.features.current.selectors import select_has_file_openned
-from analyst_klondike.features.data_context.save_action import save_to_json
+from analyst_klondike.features.data_context.save_action import save_to_yaml
 from analyst_klondike.features.app.actions import ChangeThemeAction
 from analyst_klondike.features.demo_quiz.demo import start_demo_quiz
 from analyst_klondike.state.app_dispatch import app_dispatch
@@ -45,7 +45,7 @@ class RunnerApp(App[Any]):
                 return
             if res == "save":
                 state = get_state()
-                save_to_json(state, self.app)
+                save_to_yaml(state, self.app)
             self.app.exit(0)
         has_file = select(select_has_file_openned)
         if has_file:
